/***************************************************************************//**
* \file CAPSENSE_Filter.h
* \version 2.0
*
* \brief
*   This file contains the definitions for all firmware filters implementation.
*
* \see CAPSENSE v2.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2017), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CAPSENSE_FILTER_H)
#define CY_SENSE_CAPSENSE_FILTER_H

#include "syslib/cy_syslib.h"
#include "cyfitter.h"

#include "CAPSENSE_Structure.h"
#include "CAPSENSE_Configuration.h"

/***************************************
* Function Prototypes
***************************************/

/*******************************************************************************
* LOW LEVEL API
*******************************************************************************/
/**
* \cond SECTION_CYSENSE_LOW_LEVEL
* \addtogroup group_cysense_low_level
* \{
*/

cy_status CAPSENSE_UpdateAllBaselines(void);
cy_status CAPSENSE_UpdateWidgetBaseline(uint32 widgetId);
cy_status CAPSENSE_UpdateSensorBaseline(uint32 widgetId, uint32 sensorId);

void CAPSENSE_InitializeAllBaselines(void);
void CAPSENSE_InitializeWidgetBaseline(uint32 widgetId);
void CAPSENSE_InitializeSensorBaseline(uint32 widgetId, uint32 sensorId);

#if ((CAPSENSE_ENABLE == CAPSENSE_RC_FILTER_EN) || \
     (0u != (CAPSENSE_CSD_AUTOTUNE & CAPSENSE_CSD_SS_TH_EN)))
    void CAPSENSE_InitializeAllFilters(void);
    void CAPSENSE_InitializeWidgetFilter(uint32 widgetId);
#endif /* ((CAPSENSE_ENABLE == CAPSENSE_RC_FILTER_EN) || \
           (0u != (CAPSENSE_CSD_AUTOTUNE & CAPSENSE_CSD_SS_TH_EN))) */

/** \}
* \endcond */


/*******************************************************************************
* Function Prototypes - internal functions
*******************************************************************************/
/**
* \cond SECTION_CYSENSE_INTERNAL
* \addtogroup group_cysense_internal
* \{
*/

void CAPSENSE_FtInitialize(void);

#if (0u != (CAPSENSE_CSD_AUTOTUNE & CAPSENSE_CSD_SS_TH_EN))
    void CAPSENSE_RunNoiseEnvelope(uint32 widgetId, uint32 sensorId);
    void CAPSENSE_InitializeNoiseEnvelope(uint32 widgetId, uint32 sensorId);
#endif /* (0u != (CAPSENSE_CSD_AUTOTUNE & CAPSENSE_CSD_SS_TH_EN)) */

#if (CAPSENSE_REGULAR_RC_IIR_FILTER_EN || CAPSENSE_PROX_RC_IIR_FILTER_EN)
    void CAPSENSE_InitializeIIR(uint32 widgetId, uint32 sensorId);
    void CAPSENSE_RunIIR(uint32 widgetId, uint32 sensorId);
#endif /* (CAPSENSE_REGULAR_RC_IIR_FILTER_EN || CAPSENSE_PROX_RC_IIR_FILTER_EN) */

#if (CAPSENSE_REGULAR_RC_MEDIAN_FILTER_EN || CAPSENSE_PROX_RC_MEDIAN_FILTER_EN)
    void CAPSENSE_InitializeMedian(uint32 widgetId, uint32 sensorId);
    void CAPSENSE_RunMedian(uint32 widgetId, uint32 sensorId);
#endif /* (CAPSENSE_REGULAR_RC_MEDIAN_FILTER_EN || CAPSENSE_PROX_RC_MEDIAN_FILTER_EN) */

#if (CAPSENSE_REGULAR_RC_AVERAGE_FILTER_EN || CAPSENSE_PROX_RC_AVERAGE_FILTER_EN)
    void CAPSENSE_InitializeAverage(uint32 widgetId, uint32 sensorId);
    void CAPSENSE_RunAverage(uint32 widgetId, uint32 sensorId);
#endif /* (CAPSENSE_REGULAR_RC_AVERAGE_FILTER_EN || CAPSENSE_PROX_RC_AVERAGE_FILTER_EN) */

void CAPSENSE_FtInitializeBaseline(CAPSENSE_RAM_SNS_STRUCT *ptrSensor, uint32 wdType);
uint32 CAPSENSE_FtUpdateBaseline(
                            CAPSENSE_RAM_WD_BASE_STRUCT *ptrWidgetRam,
                            CAPSENSE_RAM_SNS_STRUCT *ptrSensor,
                            uint32 wdType);

#if (CAPSENSE_POS_MEDIAN_FILTER_EN || CAPSENSE_REGULAR_RC_MEDIAN_FILTER_EN || CAPSENSE_PROX_RC_MEDIAN_FILTER_EN)
uint32 CAPSENSE_FtMedian(uint32 x1, uint32 x2, uint32 x3);
#endif /*CAPSENSE_POS_MEDIAN_FILTER_EN || CAPSENSE_REGULAR_RC_MEDIAN_FILTER_EN || CAPSENSE_PROX_RC_MEDIAN_FILTER_EN*/

uint32 CAPSENSE_FtIIR1stOrder(uint32 input, uint32 prevOutput, uint32 n, uint32 shift);

#if (CAPSENSE_POS_JITTER_FILTER_EN)
    uint32 CAPSENSE_FtJitter(uint32 input, uint32 prevOutput);
#endif /* CAPSENSE_POS_JITTER_FILTER_EN */

void CAPSENSE_FtInitializeBaselineChannel(CAPSENSE_RAM_SNS_STRUCT *ptrSensor, uint32 wdType, uint32 channel);

#if (CAPSENSE_ENABLE == CAPSENSE_RC_FILTER_EN)
    void CAPSENSE_FtRunEnabledFilters(uint32 widgetId, uint32 sensorId);
    void CAPSENSE_FtRunEnabledFiltersInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                                      CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
#endif /* (CAPSENSE_ENABLE == CAPSENSE_RC_FILTER_EN) */


#if (CAPSENSE_REGULAR_RC_IIR_FILTER_EN || CAPSENSE_PROX_RC_IIR_FILTER_EN)
    void CAPSENSE_InitializeIIRInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                                  CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
    void CAPSENSE_RunIIRInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                           CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
#endif /* (CAPSENSE_REGULAR_RC_IIR_FILTER_EN || CAPSENSE_PROX_RC_IIR_FILTER_EN) */

#if (CAPSENSE_REGULAR_RC_MEDIAN_FILTER_EN || CAPSENSE_PROX_RC_MEDIAN_FILTER_EN)
    void CAPSENSE_InitializeMedianInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                                     CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
    void CAPSENSE_RunMedianInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                              CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
#endif /* (CAPSENSE_REGULAR_RC_MEDIAN_FILTER_EN || CAPSENSE_PROX_RC_MEDIAN_FILTER_EN) */

#if (CAPSENSE_REGULAR_RC_AVERAGE_FILTER_EN || CAPSENSE_PROX_RC_AVERAGE_FILTER_EN)
    void CAPSENSE_InitializeAverageInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                                      CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
    void CAPSENSE_RunAverageInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                               CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj, uint32 wdType);
#endif /* (CAPSENSE_REGULAR_RC_AVERAGE_FILTER_EN || CAPSENSE_PROX_RC_AVERAGE_FILTER_EN) */

#if (CAPSENSE_ENABLE == CAPSENSE_ALP_FILTER_EN)
    void CAPSENSE_InitializeALP(uint32 widgetId, uint32 sensorId);
    void CAPSENSE_RunALP(uint32 widgetId, uint32 sensorId);
    void CAPSENSE_InitializeALPInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                                CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj,
                                                uint32 wdType);
    void CAPSENSE_ConfigRunALPInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                        CAPSENSE_RAM_WD_BASE_STRUCT *ptrRamWdgt,
                                        CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj,
                                        uint32 wdType);
    void CAPSENSE_RunALPInternal(CAPSENSE_PTR_FILTER_VARIANT ptrFilterHistObj,
                                        ALP_FLTR_CONFIG_STRUCT *ptrAlpFilterConfig,
                                        CAPSENSE_RAM_SNS_STRUCT *ptrSensorObj,
                                        uint32 wdType);
#endif /* (CAPSENSE_ENABLE == CAPSENSE_ALP_FILTER_EN) */

/** \}
* \endcond */

/***************************************
* Initial Parameter Constants
***************************************/
#define NOISE_ENVELOPE_SHIFT                        (0x02u)
#define NOISE_ENVELOPE_RUN_DIFF_SHIFT               (0x03u)
#define NOISE_ENVELOPE_SIGN_REG                     (0x0Fu)
#define NOISE_ENVELOPE_SIGN_REG_SHIFT               (0x01u)
#define NOISE_ENVELOPE_RESET_COUNTER                (0x0Au)
#define NOISE_ENVELOPE_4_TIMES                      (0x02u)

#endif /* End CY_SENSE_CAPSENSE_FILTER_H */


/* [] END OF FILE */
