/***************************************************************************//**
* \file CAPSENSE_SensingCSD_LL.h
* \version 2.0
*
* \brief
*   This file provides the headers of APIs specific to CSD sensing implementation.
*
* \see CAPSENSE v2.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2017), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CAPSENSE_SENSINGCSD_LL_H)
#define CY_SENSE_CAPSENSE_SENSINGCSD_LL_H

#include "cyfitter_gpio.h"
#include "syslib/cy_syslib.h"
#include "CAPSENSE_Structure.h"
#include "CAPSENSE_Configuration.h"

/****************************************************************************
* Register and mode mask definition
****************************************************************************/

#define CAPSENSE_CSD_CSDCMP_INIT                                (CAPSENSE_CSD_CSDCMP_CSDCMP_DISABLED)

/* SW_HS_P_SEL switches state for Coarse initialization of CMOD (sense path) */
#if (CAPSENSE_ENABLE == CAPSENSE_CSD_EN)
    #if (CAPSENSE_CSD__CMOD_PAD == CAPSENSE_CMOD_CONNECTION)
        #define CAPSENSE_CSD_HS_P_SEL_COARSE_CMOD               (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
    #elif (CAPSENSE_CSD__CSHIELD_PAD == CAPSENSE_CMOD_CONNECTION)
        #define CAPSENSE_CSD_HS_P_SEL_COARSE_CMOD               (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
    #else
        #define CAPSENSE_CSD_HS_P_SEL_COARSE_CMOD               (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
    #endif /* (CAPSENSE_CSD__CMOD_PAD == CAPSENSE_CMOD_CONNECTION) */
#else
    #define CAPSENSE_CSD_HS_P_SEL_COARSE_CMOD                   (0x00000000uL)
#endif /* ((CAPSENSE_ENABLE == CAPSENSE_CSD_CSX_EN) && (CAPSENSE_ENABLE == CAPSENSE_CSD_EN)) */

#if ((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_TANK_EN) && \
    (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN))
    /* SW_HS_P_SEL switches state for Coarse initialization of CTANK (sense path) */
    #if (CAPSENSE_CSD__CSH_TANK_PAD == CAPSENSE_CTANK_CONNECTION)
        #define CAPSENSE_CSD_HS_P_SEL_COARSE_TANK               (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
    #elif (CAPSENSE_CSD__CSHIELD_PAD == CAPSENSE_CTANK_CONNECTION)
        #define CAPSENSE_CSD_HS_P_SEL_COARSE_TANK               (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
    #elif (CAPSENSE_CSD__CMOD_PAD == CAPSENSE_CTANK_CONNECTION)
        #define CAPSENSE_CSD_HS_P_SEL_COARSE_TANK               (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
    #else
        #define CAPSENSE_CSD_HS_P_SEL_COARSE_TANK               (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMMA_STATIC_CLOSE)
    #endif /* (CAPSENSE_CSD__CSH_TANK_PAD == CAPSENSE_CTANK_CONNECTION) */
#else
    #define CAPSENSE_CSD_HS_P_SEL_COARSE_TANK                   (0x00000000uL)
#endif /* ((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_TANK_EN) && \
           (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN)) */

#define CAPSENSE_CSD_SW_HS_P_SEL_COARSE                         (CAPSENSE_CSD_HS_P_SEL_COARSE_CMOD | CAPSENSE_CSD_HS_P_SEL_COARSE_TANK)

/* C_mod config */
#if ((CAPSENSE_CSD__CMOD_PAD == CAPSENSE_CMOD_CONNECTION) || (CAPSENSE_CSD__CMOD_PAD == CAPSENSE_CTANK_CONNECTION))
    #define CAPSENSE_CSD_SW_FW_MOD_SEL_INIT             (CAPSENSE_CSD_SW_FW_MOD_SEL_SW_F1PM_STATIC_CLOSE |\
                                                                 CAPSENSE_CSD_SW_FW_MOD_SEL_SW_F1MA_STATIC_CLOSE |\
                                                                 CAPSENSE_CSD_SW_FW_MOD_SEL_SW_F1CA_STATIC_CLOSE)
#else
    #define CAPSENSE_CSD_SW_FW_MOD_SEL_INIT             (0x00000000uL)
#endif /* (CAPSENSE_CSD__CMOD_PAD == CAPSENSE_CMOD_CONNECTION) */

/* C_tank config */
#if ((CAPSENSE_CSD__CSH_TANK_PAD == CAPSENSE_CMOD_CONNECTION) || (CAPSENSE_CSD__CSH_TANK_PAD == CAPSENSE_CTANK_CONNECTION))
    #define CAPSENSE_CSD_SW_FW_TANK_SEL_INIT            (CAPSENSE_CSD_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE |\
                                                                 CAPSENSE_CSD_SW_FW_TANK_SEL_SW_F2MA_STATIC_CLOSE |\
                                                                 CAPSENSE_CSD_SW_FW_TANK_SEL_SW_F2CA_STATIC_CLOSE)
#else
    #define CAPSENSE_CSD_SW_FW_TANK_SEL_INIT            (0x00000000uL)
#endif /* (CAPSENSE_CSD__CSH_TANK_PAD == CAPSENSE_CTANK_CONNECTION) */

#define CAPSENSE_CSD_SW_SHIELD_SEL_INIT                 (CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCAV_HSCMP)

/* Defining default HW configuration according to settings in customizer. */
#define CAPSENSE_DEFAULT_CSD_CONFIG                 (CAPSENSE_CSD_CONFIG_FILTER_DELAY_12MHZ |\
                                                             CAPSENSE_IREF_SRC_CFG |\
                                                             CAPSENSE_PWR_MODE_CFG)

#if(CAPSENSE_SENSING_LEGACY == CAPSENSE_CSD_SENSING_METHOD)

    #if (CAPSENSE_ENABLE == CAPSENSE_CSD_AUTO_ZERO_EN)
        /* Enable CSDCMP */
        #define CAPSENSE_CSD_CSDCMP_SCAN                (CAPSENSE_CSD_CSDCMP_CSDCMP_EN_MSK |\
                                                                 CAPSENSE_CSD_CSDCMP_AZ_EN_MSK)
    #else
        /* Enable CSDCMP */
        #define CAPSENSE_CSD_CSDCMP_SCAN                (CAPSENSE_CSD_CSDCMP_CSDCMP_EN_MSK)
    #endif /* (CAPSENSE_ENABLE == CAPSENSE_CSD_AUTO_ZERO_EN) */

    #if ((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_TANK_EN) && \
        (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN))
        /* SW_HS_P_SEL switches state for Coarse initialization of CTANK (sense path) */
        #if (CAPSENSE_CSD__CSH_TANK_PAD == CAPSENSE_CTANK_CONNECTION)
            #define CAPSENSE_CSD_HS_P_SEL_SCAN_TANK                 (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #elif (CAPSENSE_CSD__CSHIELD_PAD == CAPSENSE_CTANK_CONNECTION)
            #define CAPSENSE_CSD_HS_P_SEL_SCAN_TANK                 (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #elif (CAPSENSE_CSD__CMOD_PAD == CAPSENSE_CTANK_CONNECTION)
            #define CAPSENSE_CSD_HS_P_SEL_SCAN_TANK                 (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #else
            #define CAPSENSE_CSD_HS_P_SEL_SCAN_TANK                 (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
        #endif /* (CAPSENSE_CSD__CSH_TANK_PAD == CAPSENSE_CTANK_CONNECTION) */
        #define CAPSENSE_CSD_SW_HS_P_SEL_SCAN                       (CAPSENSE_CSD_HS_P_SEL_SCAN_TANK)
    #elif(CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN)
        #define CAPSENSE_CSD_SW_HS_P_SEL_SCAN                       (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
    #else
        #define CAPSENSE_CSD_SW_HS_P_SEL_SCAN                       (CAPSENSE_CSD_WAVEFORM_STATIC_OPEN)
    #endif /* ((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_TANK_EN) && \
               (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN)) */

    /* SW_FW_MOD_SEL switches state for Coarse initialization of CMOD (sense path) */
    #define CAPSENSE_CSD_SW_FW_MOD_SEL_SCAN                 (0x00000000uL)

    #if((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN) && \
        (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_TANK_EN) && \
        (CAPSENSE_CSD__CSH_TANK_PAD == CAPSENSE_CTANK_CONNECTION))
        #define CAPSENSE_CSD_SW_FW_TANK_SEL_SCAN            (CAPSENSE_CSD_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE | \
                                                                 CAPSENSE_CSD_SW_FW_TANK_SEL_SW_F2CB_STATIC_CLOSE)
    #else
        #define CAPSENSE_CSD_SW_FW_TANK_SEL_SCAN            (0x00000000uL)
    #endif /* ((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN) && \
               (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_TANK_EN) && \
               (CAPSENSE_CSD__CSH_TANK_PAD == CAPSENSE_CTANK_CONNECTION)) */

    /* Shield switch default config */
    #if ((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN) && \
         (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_TANK_EN))
        #if (CAPSENSE_IDAC_SINKING == CAPSENSE_CSD_IDAC_CONFIG)
            #define CAPSENSE_CSD_SW_SHIELD_SEL_SCAN          (CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBG_HSCMP)
        #else
            #define CAPSENSE_CSD_SW_SHIELD_SEL_SCAN          (CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBV_HSCMP)
        #endif /* (CAPSENSE_IDAC_SINKING == CAPSENSE_CSD_IDAC_CONFIG) */
    #elif(CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN)
        #if (CAPSENSE_IDAC_SINKING == CAPSENSE_CSD_IDAC_CONFIG)
            #define CAPSENSE_CSD_SW_SHIELD_SEL_SCAN          (CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBV_PHI1 | \
                                                                     CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBG_PHI2_HSCMP)
        #else
            #define CAPSENSE_CSD_SW_SHIELD_SEL_SCAN          (CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBG_PHI1 | \
                                                                     CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBV_PHI2_HSCMP)
        #endif /* (CAPSENSE_IDAC_SINKING == CAPSENSE_CSD_IDAC_CONFIG) */
    #else
        #define CAPSENSE_CSD_SW_SHIELD_SEL_SCAN              (0x00000000uL)
    #endif /* ((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN) && \
               (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_TANK_EN)) */

    #define CAPSENSE_CSD_SW_RES_INIT                        (CAPSENSE_CSD_INIT_SWITCH_RES << CSD_SW_RES_RES_HCAV_Pos)
    #define CAPSENSE_CSD_SW_RES_SCAN                        ((CAPSENSE_CSD_SHIELD_SWITCH_RES << CSD_SW_RES_RES_HCBV_Pos) |\
                                                                     (CAPSENSE_CSD_SHIELD_SWITCH_RES << CSD_SW_RES_RES_HCBG_Pos))

    #define CAPSENSE_CSD_SHIELD_GPIO_DM                 (CY_GPIO_DM_STRONG_IN_OFF)
    #define CAPSENSE_CSD_SENSOR_HSIOM_SEL               (CAPSENSE_HSIOM_SEL_CSD_SENSE)
    #define CAPSENSE_CSD_SHIELD_HSIOM_SEL               (CAPSENSE_HSIOM_SEL_CSD_SHIELD)
    #define CAPSENSE_CSD_CMOD_HSIOM_SEL                 (CAPSENSE_HSIOM_SEL_AMUXA)

    #define CAPSENSE_DEFAULT_IDACA_BALL_MODE            (CAPSENSE_CSD_IDACA_BALL_MODE_FULL <<\
                                                                 CAPSENSE_CSD_IDACA_BALL_MODE_POS)
    #define CAPSENSE_DEFAULT_IDACB_BALL_MODE            (CAPSENSE_CSD_IDACB_BALL_MODE_FULL <<\
                                                                 CAPSENSE_CSD_IDACB_BALL_MODE_POS)

    #define CAPSENSE_DEFAULT_SENSE_DUTY_SEL             (CAPSENSE_CSD_SENSE_DUTY_SENSE_POL_PHI_HIGH)

#elif(CAPSENSE_SENSING_LOW_EMI == CAPSENSE_CSD_SENSING_METHOD)

    #if (CAPSENSE_ENABLE == CAPSENSE_CSD_AUTO_ZERO_EN)
        /* Enable CSDCMP */
        #define CAPSENSE_CSD_CSDCMP_SCAN                (CAPSENSE_CSD_CSDCMP_CSDCMP_EN_MSK  |\
                                                                 CAPSENSE_CSD_CSDCMP_CMP_PHASE_PHI2 |\
                                                                 CAPSENSE_CSD_CSDCMP_AZ_EN_MSK)
    #else
        /* Enable CSDCMP */
        #define CAPSENSE_CSD_CSDCMP_SCAN                (CAPSENSE_CSD_CSDCMP_CSDCMP_EN_MSK |\
                                                                 CAPSENSE_CSD_CSDCMP_CMP_PHASE_PHI2)
    #endif /* (CAPSENSE_ENABLE == CAPSENSE_CSD_AUTO_ZERO_EN) */

    #if(CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN)
        #define CAPSENSE_CSD_SW_HS_P_SEL_SCAN               (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
    #else
        #define CAPSENSE_CSD_SW_HS_P_SEL_SCAN               (CAPSENSE_CSD_SW_HS_P_SEL_SW_HMMB_STATIC_OPEN)
    #endif /* (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN) */

    #if (CAPSENSE_CSD__CMOD_PAD == CAPSENSE_CMOD_CONNECTION)
        #define CAPSENSE_CSD_SW_FW_MOD_SEL_SCAN             (CAPSENSE_CSD_SW_FW_MOD_SEL_SW_F1PM_STATIC_CLOSE |\
                                                                     CAPSENSE_CSD_SW_FW_MOD_SEL_SW_F1CA_PHI2)
        #define CAPSENSE_CSD_SW_FW_TANK_SEL_SCAN            (0x00000000uL)
    #else
        #define CAPSENSE_CSD_SW_FW_MOD_SEL_SCAN             (0x00000000uL)
        #define CAPSENSE_CSD_SW_FW_TANK_SEL_SCAN            (CAPSENSE_CSD_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE |\
                                                                     CAPSENSE_CSD_SW_FW_TANK_SEL_SW_F2CA_PHI2)
    #endif /* (CAPSENSE_CSD__CMOD_PAD == CAPSENSE_CMOD_CONNECTION) */

    #if(CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN)
        #if(CAPSENSE_IDAC_SINKING != CAPSENSE_CSD_IDAC_CONFIG)
            #define CAPSENSE_CSD_SW_SHIELD_SEL_SCAN             (CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBV_PHI2_HSCMP | CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBG_PHI1 | CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCAG_PHI1)
        #else
            #define CAPSENSE_CSD_SW_SHIELD_SEL_SCAN             (CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBV_PHI1 | CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCBG_PHI2_HSCMP | CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCAV_PHI1)
        #endif /* (CAPSENSE_IDAC_SINKING == CAPSENSE_CSD_IDAC_CONFIG) */
    #else
        #if(CAPSENSE_IDAC_SINKING != CAPSENSE_CSD_IDAC_CONFIG)
            #define CAPSENSE_CSD_SW_SHIELD_SEL_SCAN             (CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCAG_PHI1)
        #else
            #define CAPSENSE_CSD_SW_SHIELD_SEL_SCAN             (CAPSENSE_CSD_SW_SHIELD_SEL_SW_HCAV_PHI1)
        #endif /* (CAPSENSE_IDAC_SINKING == CAPSENSE_CSD_IDAC_CONFIG) */
    #endif /* (CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN) */

    #define CAPSENSE_CSD_SW_RES_INIT                    ((CAPSENSE_CSD_F1PM_SWITCH_RES_LE_INIT << CSD_SW_RES_RES_F1PM_Pos) |\
                                                                 (CAPSENSE_CSD_F2PT_SWITCH_RES_LE_INIT << CSD_SW_RES_RES_F2PT_Pos) |\
                                                                 (CAPSENSE_CSD_HCAG_SWITCH_RES_LE_INIT << CSD_SW_RES_RES_HCAG_Pos) |\
                                                                 (CAPSENSE_CSD_HCAV_SWITCH_RES_LE_INIT << CSD_SW_RES_RES_HCAV_Pos) |\
                                                                 (CAPSENSE_CSD_HCBG_SWITCH_RES_LE_INIT << CSD_SW_RES_RES_HCBG_Pos) |\
                                                                 (CAPSENSE_CSD_HCBV_SWITCH_RES_LE_INIT << CSD_SW_RES_RES_HCBV_Pos))

    #define CAPSENSE_CSD_SW_RES_SCAN                    ((CAPSENSE_CSD_F1PM_SWITCH_RES_LE_SCAN << CSD_SW_RES_RES_F1PM_Pos) |\
                                                                 (CAPSENSE_CSD_F2PT_SWITCH_RES_LE_SCAN << CSD_SW_RES_RES_F2PT_Pos) |\
                                                                 (CAPSENSE_CSD_HCAG_SWITCH_RES_LE_SCAN << CSD_SW_RES_RES_HCAG_Pos) |\
                                                                 (CAPSENSE_CSD_HCAV_SWITCH_RES_LE_SCAN << CSD_SW_RES_RES_HCAV_Pos) |\
                                                                 (CAPSENSE_CSD_HCBG_SWITCH_RES_LE_SCAN << CSD_SW_RES_RES_HCBG_Pos) |\
                                                                 (CAPSENSE_CSD_HCBV_SWITCH_RES_LE_SCAN << CSD_SW_RES_RES_HCBV_Pos))

    #define CAPSENSE_CSD_SHIELD_GPIO_DM                 (CY_GPIO_DM_ANALOG)
    #define CAPSENSE_CSD_SENSOR_HSIOM_SEL               (CAPSENSE_HSIOM_SEL_AMUXA)
    #define CAPSENSE_CSD_SHIELD_HSIOM_SEL               (CAPSENSE_HSIOM_SEL_AMUXB)
    #define CAPSENSE_CSD_CMOD_HSIOM_SEL                 (CAPSENSE_HSIOM_SEL_GPIO)

    #define CAPSENSE_DEFAULT_IDACA_BALL_MODE            (CAPSENSE_CSD_IDACA_BALL_MODE_PHI2 <<\
                                                                 CAPSENSE_CSD_IDACA_BALL_MODE_POS)
    #define CAPSENSE_DEFAULT_IDACB_BALL_MODE            (CAPSENSE_CSD_IDACB_BALL_MODE_FULL <<\
                                                                 CAPSENSE_CSD_IDACB_BALL_MODE_POS)

    #if(CAPSENSE_IDAC_SINKING != CAPSENSE_CSD_IDAC_CONFIG)
        #define CAPSENSE_DEFAULT_SENSE_DUTY_SEL             (0x00000000uL)
    #else
        #define CAPSENSE_DEFAULT_SENSE_DUTY_SEL             (CAPSENSE_CSD_SENSE_DUTY_SENSE_POL_MSK)
    #endif /* (CAPSENSE_IDAC_SINKING != CAPSENSE_CSD_IDAC_CONFIG) */

#elif(CAPSENSE_SENSING_FULL_WAVE == CAPSENSE_CSD_SENSING_METHOD)
#else
    #error "Not supported sensing method."
#endif /* (CAPSENSE_SENSING_LEGACY == CAPSENSE_CSD_SENSING_METHOD) */


/***************************************
* API Constants
***************************************/
/* Definition of time interval that is enough for charging 100nF capacitor */
#define CAPSENSE_CSD_AVG_CYCLES_PER_LOOP                    (5u)
#define CAPSENSE_CSD_MAX_CHARGE_TIME_US                     (100u)
#define CAPSENSE_CSD_PRECHARGE_WATCHDOG_CYCLES_NUM          (((CAPSENSE_CPU_CLOCK_FREQ_MHZ) * (CAPSENSE_CSD_MAX_CHARGE_TIME_US)) /\
                                                                        (CAPSENSE_CSD_AVG_CYCLES_PER_LOOP))

#define CAPSENSE_CSD_IDAC_MOD_BITS_USED                     (7u)
#define CAPSENSE_CAL_MIDDLE_BIT                             (1uL << (CAPSENSE_CSD_IDAC_MOD_BITS_USED - 1u))
/* Increased scan time duration to cover coarse and fine init cycles */
#define CAPSENSE_MAX_17_BITS_VALUE                          (0x0001FFFFLu)
#define CAPSENSE_MAX_SCAN_TIME                              ((CAPSENSE_MAX_17_BITS_VALUE * CAPSENSE_CSD_SCANSPEED_DIVIDER) /\
                                                                        (CYDEV_CLK_PERICLK__MHZ))
#define CAPSENSE_CALIBR_WATCHDOG_CYCLES_NUM                 (((CAPSENSE_CPU_CLOCK_FREQ_MHZ) * (CAPSENSE_MAX_SCAN_TIME)) /\
                                                                        (CAPSENSE_CSD_AVG_CYCLES_PER_LOOP))

#define CAPSENSE_DELAY_EXTRACYCLES_NUM                      (9u)

/* Calibration constants */
#define CAPSENSE_IDAC_MOD_MAX_CALIB_ERROR                   (10u)

#if (CAPSENSE_IDAC_GAIN_HIGH == CAPSENSE_CSD_IDAC_GAIN)
    #define CAPSENSE_CSD_IDAC_GAIN_VALUE_NA                 (2400u)
#elif (CAPSENSE_IDAC_GAIN_MEDIUM == CAPSENSE_CSD_IDAC_GAIN)
    #define CAPSENSE_CSD_IDAC_GAIN_VALUE_NA                 (300u)
#else
    #define CAPSENSE_CSD_IDAC_GAIN_VALUE_NA                 (37u)
#endif /* (CAPSENSE_IDAC_GAIN_HIGH == CAPSENSE_CSD_IDAC_GAIN) */

/* Defining the drive mode of pins depending on the Inactive sensor connection setting in the Component customizer. */
#if(CAPSENSE_SNS_CONNECTION_GROUND == CAPSENSE_CSD_INACTIVE_SNS_CONNECTION)
    #define CAPSENSE_CSD_INACTIVE_SNS_GPIO_DM               (CY_GPIO_DM_STRONG)
#elif(CAPSENSE_SNS_CONNECTION_HIGHZ == CAPSENSE_CSD_INACTIVE_SNS_CONNECTION)
    #define CAPSENSE_CSD_INACTIVE_SNS_GPIO_DM               (CY_GPIO_DM_ANALOG)
#elif(CAPSENSE_SNS_CONNECTION_SHIELD == CAPSENSE_CSD_INACTIVE_SNS_CONNECTION)
    #define CAPSENSE_CSD_INACTIVE_SNS_GPIO_DM               (CY_GPIO_DM_STRONG_IN_OFF)
#else
    #error "Unsupported inactive connection for the inactive sensors."
#endif /* (CAPSENSE_SNS_CONNECTION_GROUND == CAPSENSE_CSD_INACTIVE_SNS_CONNECTION) */


/* Clock Source Mode */
#if (CAPSENSE_CLK_SOURCE_DIRECT == CAPSENSE_CSD_SNS_CLK_SOURCE)
    #define CAPSENSE_DEFAULT_MODULATION_MODE                (CAPSENSE_CLK_SOURCE_DIRECT)
#elif (CAPSENSE_CLK_SOURCE_PRSAUTO == CAPSENSE_CSD_SNS_CLK_SOURCE)
    #define CAPSENSE_DEFAULT_MODULATION_MODE                (CAPSENSE_CLK_SOURCE_SSC2)
#elif ((CAPSENSE_CLK_SOURCE_PRS8) == CAPSENSE_CSD_SNS_CLK_SOURCE)
    #define CAPSENSE_DEFAULT_MODULATION_MODE                (CAPSENSE_CSD_SNS_CLK_SOURCE)
#elif ((CAPSENSE_CLK_SOURCE_PRS12) == CAPSENSE_CSD_SNS_CLK_SOURCE)
    #define CAPSENSE_DEFAULT_MODULATION_MODE                (CAPSENSE_CSD_SNS_CLK_SOURCE)
#else
    #define CAPSENSE_DEFAULT_MODULATION_MODE                (CAPSENSE_CSD_SNS_CLK_SOURCE)
#endif /* (CAPSENSE_CLK_SOURCE_DIRECT != CAPSENSE_CSD_SNS_CLK_SOURCE) */

/* IDACs Ranges */
#if (CAPSENSE_IDAC_GAIN_LOW == CAPSENSE_CSD_IDAC_GAIN)
    #define CAPSENSE_DEFAULT_IDACA_RANGE                    (CAPSENSE_CSD_IDACA_RANGE_IDAC_LO << CAPSENSE_CSD_IDACA_RANGE_POS)
    #define CAPSENSE_DEFAULT_IDACB_RANGE                    (CAPSENSE_CSD_IDACB_RANGE_IDAC_LO << CAPSENSE_CSD_IDACB_RANGE_POS)
#elif (CAPSENSE_IDAC_GAIN_MEDIUM == CAPSENSE_CSD_IDAC_GAIN)
    #define CAPSENSE_DEFAULT_IDACA_RANGE                    (CAPSENSE_CSD_IDACA_RANGE_IDAC_MED << CAPSENSE_CSD_IDACA_RANGE_POS)
    #define CAPSENSE_DEFAULT_IDACB_RANGE                    (CAPSENSE_CSD_IDACB_RANGE_IDAC_MED << CAPSENSE_CSD_IDACB_RANGE_POS)
#else
    #define CAPSENSE_DEFAULT_IDACA_RANGE                    (CAPSENSE_CSD_IDACA_RANGE_IDAC_HI << CAPSENSE_CSD_IDACA_RANGE_POS)
    #define CAPSENSE_DEFAULT_IDACB_RANGE                    (CAPSENSE_CSD_IDACB_RANGE_IDAC_HI << CAPSENSE_CSD_IDACB_RANGE_POS)
#endif

/* IDACs Polarities */
#if (CAPSENSE_IDAC_SINKING == CAPSENSE_CSD_IDAC_CONFIG)
    #define CAPSENSE_DEFAULT_IDACA_POLARITY                 (CAPSENSE_CSD_IDACA_POLARITY_VDDA_SNK << CAPSENSE_CSD_IDACA_POLARITY_POS)
    #define CAPSENSE_DEFAULT_IDACB_POLARITY                 (CAPSENSE_CSD_IDACB_POLARITY_VDDA_SNK << CAPSENSE_CSD_IDACB_POLARITY_POS)
#else
    #define CAPSENSE_DEFAULT_IDACA_POLARITY                 (CAPSENSE_CSD_IDACA_POLARITY_VSSA_SRC << CAPSENSE_CSD_IDACA_POLARITY_POS)
    #define CAPSENSE_DEFAULT_IDACB_POLARITY                 (CAPSENSE_CSD_IDACB_POLARITY_VSSA_SRC << CAPSENSE_CSD_IDACB_POLARITY_POS)
#endif /* (CAPSENSE_IDAC_SINKING == CAPSENSE_CSD_IDAC_CONFIG) */


#if(CAPSENSE_VREF_SRSS != CAPSENSE_CSD_VREF_SOURCE)
    #define CAPSENSE_CSD_SW_REFGEN_VREF_SRC                 (CAPSENSE_CSD_SW_REFGEN_SEL_SW_SGRP_MSK)
#else
    #define CAPSENSE_CSD_SW_REFGEN_VREF_SRC                 (CAPSENSE_CSD_SW_REFGEN_SEL_SW_SGR_MSK)
#endif /* (CAPSENSE_VREF_SRSS != CAPSENSE_CSD_VREF_SOURCE) */


/* IDAC legs configuration */
#if ((CAPSENSE_ENABLE == CAPSENSE_CSD_IDAC_COMP_EN) && \
     (CAPSENSE_ENABLE == CAPSENSE_CSD_DEDICATED_IDAC_COMP_EN))
        #define CAPSENSE_DEFAULT_SW_REFGEN_SEL              (CAPSENSE_CSD_SW_REFGEN_VREF_SRC | CAPSENSE_CSD_SW_REFGEN_SEL_SW_IAIB_MSK)
        #define CAPSENSE_DEFAULT_IDACB_LEG1_MODE            (CAPSENSE_CSD_IDACB_LEG1_EN_MSK |\
                                                                    (CAPSENSE_CSD_IDACB_LEG1_MODE_CSD_STATIC << CAPSENSE_CSD_IDACB_LEG1_MODE_POS))
#else
        #define CAPSENSE_DEFAULT_SW_REFGEN_SEL              (CAPSENSE_CSD_SW_REFGEN_VREF_SRC)
        #define CAPSENSE_DEFAULT_IDACB_LEG1_MODE            (CAPSENSE_CSD_IDACB_LEG1_MODE_GP_STATIC << CAPSENSE_CSD_IDACB_LEG1_MODE_POS)
#endif /* ((CAPSENSE_ENABLE == CAPSENSE_CSD_IDAC_COMP_EN) && \
           (CAPSENSE_ENABLE == CAPSENSE_CSD_DEDICATED_IDAC_COMP_EN)) */


#if ((CAPSENSE_ENABLE == CAPSENSE_CSD_IDAC_COMP_EN) && \
     (CAPSENSE_DISABLE == CAPSENSE_CSD_DEDICATED_IDAC_COMP_EN))
        #define CAPSENSE_DEFAULT_IDACB_LEG2_MODE            (CAPSENSE_CSD_IDACA_LEG2_EN_MSK |\
                                                                    (CAPSENSE_CSD_IDACA_LEG2_MODE_CSD_STATIC << CAPSENSE_CSD_IDACA_LEG2_MODE_POS))
#else
        #define CAPSENSE_DEFAULT_IDACB_LEG2_MODE            (CAPSENSE_CSD_IDACA_LEG2_MODE_GP_STATIC << CAPSENSE_CSD_IDACA_LEG2_MODE_POS)
#endif /* ((CAPSENSE_ENABLE == CAPSENSE_CSD_IDAC_COMP_EN) && \
        (CAPSENSE_DISABLE == CAPSENSE_CSD_DEDICATED_IDAC_COMP_EN)) */

/* IDACs register configuration is based on the Component configuration */
#define CAPSENSE_IDAC_MOD_DEFAULT_CFG                       (CAPSENSE_DEFAULT_IDACA_RANGE | \
                                                                     CAPSENSE_DEFAULT_IDACA_POLARITY | \
                                                                     CAPSENSE_DEFAULT_IDACA_BALL_MODE | \
                                                                    (CAPSENSE_CSD_IDACA_LEG1_MODE_CSD << CAPSENSE_CSD_IDACA_LEG1_MODE_POS) | \
                                                                     CAPSENSE_CSD_IDACA_LEG1_EN_MSK | \
                                                                     CAPSENSE_DEFAULT_IDACB_LEG2_MODE)

#define CAPSENSE_IDAC_COMP_DEFAULT_CFG                      (CAPSENSE_DEFAULT_IDACB_RANGE | \
                                                                     CAPSENSE_DEFAULT_IDACB_POLARITY | \
                                                                     CAPSENSE_DEFAULT_IDACB_BALL_MODE | \
                                                                     CAPSENSE_DEFAULT_IDACB_LEG1_MODE | \
                                                                    (CAPSENSE_CSD_IDACB_LEG2_MODE_GP_STATIC << CAPSENSE_CSD_IDACB_LEG2_MODE_POS))

#define CAPSENSE_IDAC_MOD_CALIBRATION_CFG                   (CAPSENSE_DEFAULT_IDACA_RANGE | \
                                                                     CAPSENSE_DEFAULT_IDACA_POLARITY | \
                                                                     CAPSENSE_DEFAULT_IDACA_BALL_MODE | \
                                                                    (CAPSENSE_CSD_IDACA_LEG1_MODE_CSD << CAPSENSE_CSD_IDACA_LEG1_MODE_POS) | \
                                                                     CAPSENSE_CSD_IDACA_LEG1_EN_MSK | \
                                                                    (CAPSENSE_CSD_IDACA_LEG2_MODE_GP_STATIC << CAPSENSE_CSD_IDACA_LEG2_MODE_POS))

#define CAPSENSE_IDAC_COMP_CALIBRATION_CFG                  (CAPSENSE_DEFAULT_IDACB_RANGE | \
                                                                     CAPSENSE_DEFAULT_IDACB_POLARITY | \
                                                                     CAPSENSE_DEFAULT_IDACB_BALL_MODE | \
                                                                    (CAPSENSE_CSD_IDACB_LEG1_MODE_GP_STATIC << CAPSENSE_CSD_IDACB_LEG1_MODE_POS) | \
                                                                    (CAPSENSE_CSD_IDACB_LEG2_MODE_GP_STATIC << CAPSENSE_CSD_IDACB_LEG2_MODE_POS))

/***************************************
* Global software variables
***************************************/

extern uint32 CAPSENSE_configCsd;

#if (CAPSENSE_ENABLE == CAPSENSE_CSD_NOISE_METRIC_EN)
    extern uint8 CAPSENSE_badConversionsNum;
#endif /* (CAPSENSE_ENABLE == CAPSENSE_CSD_NOISE_METRIC_EN) */

#if (CAPSENSE_CSD_SS_DIS != CAPSENSE_CSD_AUTOTUNE)
    /* Stores IDAC and raw count that corresponds to a sensor with maximum Cp within a widget */
    extern uint8 CAPSENSE_calibratedIdac;
    extern uint16 CAPSENSE_calibratedRawcount;
    #if (CAPSENSE_CSD_MATRIX_WIDGET_EN || CAPSENSE_CSD_TOUCHPAD_WIDGET_EN)
        extern uint8 CAPSENSE_calibratedIdacRow;
        extern uint16 CAPSENSE_calibratedRawcountRow;
    #endif /*(CAPSENSE_CSD_MATRIX_WIDGET_EN || CAPSENSE_CSD_TOUCHPAD_WIDGET_EN) */
#endif /* (CAPSENSE_CSD_SS_DIS != CAPSENSE_CSD_AUTOTUNE) */

/***************************************
* Function Prototypes
**************************************/

/* Interrupt handler */
extern void CAPSENSE_CSDPostSingleScan(void);
extern void CAPSENSE_CSDPostMultiScan(void);

#if (CAPSENSE_ENABLE == CAPSENSE_CSD_GANGED_SNS_EN)
    extern void CAPSENSE_CSDPostMultiScanGanged(void);
#endif /* (CAPSENSE_ENABLE == CAPSENSE_CSD_GANGED_SNS_EN) */


/**
* \cond SECTION_CYSENSE_LOW_LEVEL
* \addtogroup group_cysense_low_level
* \{
*/

void CAPSENSE_CSDSetupWidget(uint32 widgetId);
void CAPSENSE_CSDSetupWidgetExt(uint32 widgetId, uint32 sensorId);
void CAPSENSE_CSDScan(void);
void CAPSENSE_CSDScanExt(void);
#if ((CAPSENSE_CSD_SS_DIS != CAPSENSE_CSD_AUTOTUNE) || \
     (CAPSENSE_ENABLE == CAPSENSE_CSD_IDAC_AUTOCAL_EN))
    cy_status CAPSENSE_CSDCalibrateWidget(uint32 widgetId, uint32 target);
#endif /* ((CAPSENSE_CSD_SS_DIS != CAPSENSE_CSD_AUTOTUNE) || \
           (CAPSENSE_ENABLE == CAPSENSE_CSD_IDAC_AUTOCAL_EN)) */
void CAPSENSE_CSDConnectSns(CAPSENSE_FLASH_IO_STRUCT const *snsAddrPtr);
void CAPSENSE_CSDDisconnectSns(CAPSENSE_FLASH_IO_STRUCT const *snsAddrPtr);

/** \}
* \endcond */

/*****************************************************
* Function Prototypes - internal Low Level functions
*****************************************************/
/**
* \cond SECTION_CYSENSE_INTERNAL
* \addtogroup group_cysense_internal
* \{
*/

void CAPSENSE_SsCSDInitialize(void);
void CAPSENSE_SsCSDStartSample(void);
void CAPSENSE_SsCSDSetUpIdacs(CAPSENSE_RAM_WD_BASE_STRUCT const *ptrWdgt);
void CAPSENSE_SsCSDConfigClock(void);
void CAPSENSE_SsCSDElectrodeCheck(void);
#if ((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN) && \
     (0u != CAPSENSE_CSD_TOTAL_SHIELD_COUNT))
    void CAPSENSE_SsCSDDisableShieldElectrodes(void);
#endif /* ((CAPSENSE_ENABLE == CAPSENSE_CSD_SHIELD_EN) && \
           (0u != CAPSENSE_CSD_TOTAL_SHIELD_COUNT)) */
uint32 CAPSENSE_SsCSDGetNumberOfConversions(uint32 snsClkDivider, uint32 resolution, uint32 snsClkSrc);
void CAPSENSE_SsCSDCalculateScanDuration(CAPSENSE_RAM_WD_BASE_STRUCT const *ptrWdgt);
void CAPSENSE_SsCSDConnectSensorExt(uint32 widgetId, uint32 sensorId);
void CAPSENSE_SsCSDDisconnectSnsExt(uint32 widgetId, uint32 sensorId);

#if ((CAPSENSE_CSD_SS_DIS != CAPSENSE_CSD_AUTOTUNE) || \
     (CAPSENSE_ENABLE == CAPSENSE_SELF_TEST_EN) || \
     (CAPSENSE_ENABLE == CAPSENSE_CSD_IDAC_AUTOCAL_EN))
#endif /* ((CAPSENSE_CSD_SS_DIS != CAPSENSE_CSD_AUTOTUNE) || \
           (CAPSENSE_ENABLE == CAPSENSE_SELF_TEST_EN) || \
           (CAPSENSE_ENABLE == CAPSENSE_CSD_IDAC_AUTOCAL_EN)) */

/** \}
* \endcond */

/***************************************
* Global software variables
***************************************/
extern uint32 CAPSENSE_configCsd;
/* Interrupt handler */
extern void CAPSENSE_CSDPostSingleScan(void);
extern void CAPSENSE_CSDPostMultiScan(void);
#if (CAPSENSE_ENABLE == CAPSENSE_CSD_GANGED_SNS_EN)
extern void CAPSENSE_CSDPostMultiScanGanged(void);
#endif /* (CAPSENSE_ENABLE == CAPSENSE_CSD_GANGED_SNS_EN) */
#if (CAPSENSE_ENABLE == CAPSENSE_CSD_NOISE_METRIC_EN)
    extern uint8 CAPSENSE_badConversionsNum;
#endif /* (CAPSENSE_ENABLE == CAPSENSE_CSD_NOISE_METRIC_EN) */

#endif /* End CY_SENSE_CAPSENSE_SENSINGCSD_LL_H */


/* [] END OF FILE */
