//===========================================================
// PSoC63 BLE Project
//-----------------------------------------------------------
// File Name   : display.c
// Description : E-INK Display related Routine
//-----------------------------------------------------------
// History :
// Rev.01 2018.05.20 M.Maruyama First Release
//-----------------------------------------------------------
// Copyright (C) 2018 M.Maruyama
//===========================================================

#include "cy_eink_library.h"
#include "display_contents.h"

// Definition of Ambient Temperature
#define AMBIENT_TEMPERATURE (int8_t) (25)

// Definition of the coordinates of a full image frame
#define IMAGE_COORDINATES  {0, 58, 0, 176}

// Origin of the text coordinates
#define TEXT_ORIGIN {0x00u, 0x05u}

// Flag that indicates if the E-INK display has been detected
bool static displayDetected = false;

// Frame buffer used for display operations
cy_eink_frame_t frameBuffer[CY_EINK_FRAME_SIZE];

//---------------------------------------------
// Initialization of E-INK display hardware
//---------------------------------------------
void Init_Display(void)
{ 
    // Initialize the E-INK display hardware
    Cy_EINK_Start(AMBIENT_TEMPERATURE);
    
    // Power on the display and check if the operation is successful
    if (Cy_EINK_Power(CY_EINK_ON)== CY_EINK_OPERATION_SUCCESS)
    {
        // Clear the display to white background
        Cy_EINK_Clear(CY_EINK_WHITE_BACKGROUND, CY_EINK_POWER_MANUAL);
        Cy_EINK_Power(CY_EINK_OFF);
        
        // Set the flag that indicates if the E-INK display has been detected
        displayDetected = true;
    }
}

//-----------------------------
// Display Welcome Message
//-----------------------------
void Display_Welcome(void)
{
    // Coordinates of a full-image and text origin
    const uint8_t   imageCoordinates[]  = IMAGE_COORDINATES;
    const uint8_t   textOrigin[]        = TEXT_ORIGIN;
    
    // if the E-INK display has been detected
    if (displayDetected)
    {
        // Load the image that has the logo and the heading to the frame buffer
        Cy_EINK_ImageToFrameBuffer(frameBuffer, (cy_eink_frame_t*)logoTORAGI,
                                (uint8_t*) imageCoordinates);
        // Load the text that stores instructions to the frame buffer
        Cy_EINK_TextToFrameBuffer(frameBuffer, (char*)textPsoc63,
                           CY_EINK_FONT_8X12BLACK, (uint8_t*) textOrigin);
        
        // Write the frame buffer to the E-INK display.
        Cy_EINK_ShowFrame(CY_EINK_WHITE_FRAME, frameBuffer, CY_EINK_FULL_2STAGE, CY_EINK_POWER_AUTO);
    }
}

//===========================================================
// End of Program
//===========================================================
